@@ -1,12 +1,11 @@
 #!/usr/bin/env python
 
-from uacs.function import *
+import uacs
 import os
-import __init__
 import sys
 
 sys.stdout = open(os.devnull, 'w')
-restore(False)
+uacs.restore(False)
 
 # --------------* Variables *-------------- #
 
@@ -34,14 +33,14 @@ def main():
             verbose = False
 
     except:
-        __init__.run_daemon()  # Run daemon
+        uacs.run_daemon()  # Run daemon
 
     # ---* Command *--- #
     try:
         if str(sys.argv[command]) == "append":
             try:
                 argv_service = sys.argv[command + 1]
-                append(argv_service, verbose)
+                uacs.append(argv_service, verbose)
             except:
                 print("commande usage: uacs append 'service_to_append'")
 
@@ -52,22 +51,22 @@ def main():
             docs.close()
 
         elif str(sys.argv[command]) == "start":
-            __init__.run_daemon()
+            uacs.daemon.run_daemon()
 
         elif str(sys.argv[command]) == "send_mail":
-            send_mail("test", verbose)
+            uacs.send_mail("test", verbose)
 
         elif str(sys.argv[command]) == "restore":
-            restore(verbose)
+            uacs.restore(verbose)
 
         elif str(sys.argv[command]) == "restore_service":
-            restore_service(verbose)
+            uacs.restore_service(verbose)
 
         elif str(sys.argv[command]) == "restore_email":
-            restore_email(verbose)
+            uacs.restore_email(verbose)
 
         elif str(sys.argv[command]) == "init":
-            init()
+            uacs.init()
 
         elif str(sys.argv[command]) == "stop":
             pass  # running = False
